@@ -2,13 +2,28 @@ from django.conf import settings as django_settings
 from django.utils.module_loading import import_string
 
 
+#
+# Mostly inspired by `rest_framework.settings`
+#
+
 IMPORT_SETTINGS = [
-    "EMAIL_USER_ABSTRACT_BASE_CLASS",
+    "OTP_SENDER_CLASS",
+    "GET_OTP_SERVICE_CLASS",
+    "CHECK_OTP_SERVICE_CLASS",
 ]
 DEFAULT_SETTINGS = {
-    "EMAIL_USER_ABSTRACT_BASE_CLASS": "swap_user.to_email.models.AbstractEmailUser",
+    # services
+    "OTP_SENDER_CLASS": "swap_user.otp.senders.StdOutOTPSender",
+    "GET_OTP_SERVICE_CLASS": "swap_user.otp.services.GetOTPService",
+    "CHECK_OTP_SERVICE_CLASS": "swap_user.otp.services.CheckOTPService",
+    # patterns
+    "INVALID_LOGIN_PATTERN": "user:invalid:login:{user_id}",
+    "BANNED_USER_PATTERN": "user:banned:{user_id}",
     "OTP_PATTERN": "user:otp:{user_id}",
-    "OTP_TIMEOUT": 60,
+    # constant values
+    "BANNED_USER_TIMEOUT": 60 * 60 * 24,  # 24 hours
+    "OTP_TIMEOUT": 60,  # 60 seconds
+    "MAX_INVALID_LOGIN_ATTEMPTS": 3,
     "OTP_ALPHABET": "0123456789",
     "OTP_LENGTH": 5,
 }
@@ -23,6 +38,10 @@ MAPPING = {
 
 
 class SwapUserSettings:
+    """
+    Settings object mostly inspired from `rest_framework.settings`.
+    """
+
     def make_import(self, item, path):
         val = import_string(path)
         setattr(self, item, val)
